v3.1.1
======

No significant changes.


v3.1.0
======

Rely on PEP 420 for namespace package.

v3.0.0
======

Require Python 3.6.

2.0
===

Switch to `pkgutil namespace technique
<https://packaging.python.org/guides/packaging-namespace-packages/#pkgutil-style-namespace-packages>`_
for the ``jaraco`` namespace.

1.2
===

Refresh package.

1.1
===

Refresh package.

1.0
===

Initial import from jaraco.net.
